
Publications
==============

[1] Garyfallidis E, Brett M, Nimmo-Smith I (2010), “Fast Dimensionality Reduction for Brain Tractography Clustering”, 16th Annual Meeting of the Organization for Human Brain Mapping.

[2] Garyfallidis E, Brett M, Tsiaras V, Vogiatzis G, Nimmo-Smith I (2010), “Identification of corresponding tracks in diffusion MRI tractographies” Proc. Intl. Soc. Mag. Reson. Med. 18

[3] Correia M.M, Williams G.B, Yeh F-C, Nimmo-Smith I, Garyfallidis E (2011), “Robustness of diffusion scalar metrics when estimated with Generalized Q-Sampling Imaging acquisition schemes”, Proc. Intl. Soc. Mag. Reson. Med. 19

[4] Chamberlain SR, Hampshire A, Menzies LA, Garyfallidis E, Grant JE, Odlaug BL, Craig K, Fineberg N, Sahakian BJ (2010), “Reduced brain white matter integrity in trichotillomania: a diffusion tensor imaging study.” Arch Gen Psychiatry 67(9):965-71

[5] Garyfallidis E, Brett M, Amirbekian B, Nguyen C, Yeh F-C, Olivetti E, Halchenko Y, Nimmo-Smith I "Dipy - a novel software library for diffusion MR and tractography", 17th Annual Meeting of the Organization for Human Brain Mapping.

[6] Yeh F-C, Wedeen VJ, Tseng WY,  "Generalized Q-Sampling Imaging"

A short note
--------------

* If you are using the Local Skeleton Clustering (LSC) method please cite [1].

* If you are using track correspondence use [2].

* If you are using Generalized Q-sampling please cite [7].

* For everything else please cite [6].
 
